<?php
/*
Plugin Name: Do We Have Testing Kits
Plugin URI: https://wordpress.org/plugins/do-we-have-testing-kits/
Description: A toggle that switches between two bits of content.
Version: 2.6
Author: Colin Tomele
Author URI: http://heightslibrary.org
License: GPLv2 or later
Text Domain: do-we-have-testing-kits
*/

$dwhtk = new do_we_have_testing_kits;

class do_we_have_testing_kits {
	
	function __construct() {
		define( 'DWHTK_URL', plugin_dir_url( __FILE__ ) );
		
		register_activation_hook( DWHTK_URL, 	[ $this, 'dwhtk_activate' ] );
		register_deactivation_hook( DWHTK_URL, 	[ $this, 'dwhtk_deactivate' ] );
		register_uninstall_hook( DWHTK_URL, 	[ $this, 'dwhtk_uninstall' ] );
		
		add_action( 'admin_init', 				[$this, 'register_dwhtk_settings'] );				
		add_action( 'admin_menu', 				[$this, 'init'] );
		add_action( 'admin_enqueue_scripts', 	[$this, 'enqueue'] );		
		add_action( 'wp_dashboard_setup', 		[$this, 'dwhtk_widget']);
		add_action( 'wp_ajax_is_checked', 		[ $this, 'is_checked' ] );
		add_shortcode( 'dwhtk', [ $this, 'show_content' ] );
		add_shortcode( 'dwhtktime', [ $this, 'show_time' ] );
	}
	
	function show_time( $args ) {
		
		$timestamp = get_option( 'dwhtk_time' );
		$date = new DateTime();
		$date->setTimestamp( $timestamp );
		
		$format_type = ( empty( $args['format'] ) ) ? null : $args['format'];
		
		switch(  $format_type ) {
			case 1:
				$format = 'Y-m-d h:i a';
				break;
			case 2:
				$format = 'l, jS \of F Y, h:i A';
				break;
			case 3:
			default:
				$format = 'm-d-Y, h:i a';
				break;
		}
		
		
		$converted = date( 'Y-m-d H:i:s', $timestamp );
		
		return get_date_from_gmt( $converted, $format );
	}
	function show_content() {
		if( true == get_option( 'dwhtk_status' ) ) {
			$content = do_shortcode( get_option( 'dwhtk_yes_content' ) );
		} else {
			$content = do_shortcode( get_option( 'dwhtk_no_content' ) );
		}
		
		return $content;
	}
	
	function dwhtk_activate() {
		update_option( 'dwhtk_time', current_time( 'timestamp', true ) );
	}
	
	function dwhtk_deactivate() {
		
	}
	
	function dwhtk_section_content() {
		
		echo '<p>'. __( 'Please enter the content that you would like for each state of the big switch.', 'do-we-have-testing-kits' ) . '</p>';
		echo '<p>'.  __( 'To display the content on a page or post, use the shortcode [\'dwhtk\'].', 'do-we-have-testing-kits' ) . '</p>';
		echo '<p>'.  __( 'The shortcode [dwhtktime] can be used on pages, posts, and even in the content boxes of the plugin itself.', 'do-we-have-testing-kits' ) . '</p>';

		echo '<h3>'.  __( 'Time formatting', 'do-we-have-testing-kits' ) . '</h3>';
		echo '<p>'.  __( 'Use the following option in the shortcode to change the display format of the time.', 'do-we-have-testing-kits' ) . '</p>';
	
		echo '<div style="display:flex; width: 600px;">
			<div style="flex:1">';
		_e( '[dwhtktime format=1]', 'do-we-have-testing-kits' );
		echo '	</div>
			<div style="flex:1">';
		_e( '2022-01-19 01:02 pm', 'do-we-have-testing-kits' );
		echo '</div>
		</div>';
		
		echo '<div style="display:flex; width: 600px;">
			<div style="flex:1">';
		_e( '[dwhtktime format=2]', 'do-we-have-testing-kits' );
		echo '	</div>
			<div style="flex:1">';
		_e( 'Wednesday, 19th of January 2022, 01:02 PM', 'do-we-have-testing-kits' );
		echo '</div>
		</div>';
		
		echo '<div style="display:flex; width: 600px;">
			<div style="flex:1">';
		_e( '[dwhtktime format=3]', 'do-we-have-testing-kits' );
		echo '	</div>
			<div style="flex:1">';
		_e( '01-19-2022, 01:02 pm', 'do-we-have-testing-kits' );
		echo '</div>
		</div>';
		
		echo '<h3>Content Settings</h3>';
	}
	
	function register_dwhtk_settings() {
		add_settings_section( 
			'dwhtk_section', 
			__( 'Do We Have Test Kits Instructions', 'do-we-have-testing-kits' ), 
			[ $this, 'dwhtk_section_content' ], 
			'dwhtk-settings' );
		
		
		$args = array(
            'type' => 'boolean', 
            'default' => false,
            );
			
		add_settings_field( 
			'dwhtk_status', 
			__( 'Current status', 'do-we-have-testing-kits' ), 
			[ $this, 'show_status'], 
			'dwhtk-settings', 
			'dwhtk_hidden' );
		
		register_setting( 'dwhtk_section', 'dwhtk_status', $args );
		
		$args = array(
            'type' => 'string', 
            'default' => null,
			'sanitize_callback' => 'wp_kses_post',
            );
			
		add_settings_field( 
			'dwhtk_yes_content', 
			__( 'Content for "We Have Kits"', 'do-we-have-testing-kits' ), 
			[ $this, 'dwhtk_yes_content'], 
			'dwhtk-settings', 
			'dwhtk_section' );
		
		register_setting( 'dwhtk_section', 'dwhtk_yes_content', $args );	
		
		$args = array(
            'type' => 'string', 
            'default' => null,
			'sanitize_callback' => 'wp_kses_post',
            );
			
		add_settings_field( 
			'dwhtk_no_content', 
			__( 'Content for "We Are Out of Kits"', 'do-we-have-testing-kits' ), 
			[ $this, 'dwhtk_no_content'], 
			'dwhtk-settings', 
			'dwhtk_section' );
		
		register_setting( 'dwhtk_section', 'dwhtk_no_content', $args );
	} 


	function dwhtk_uninstall() {		
		unregister_setting( 'dwhtk_options', 'dwhtk_status' );
		unregister_setting( 'dwhtk_options', 'dwhtk_yes_msg' ); 
		unregister_setting( 'dwhtk_options', 'dwhtk_no_msg' ); 		
	}
	
	function is_checked() {
		
		ob_start();
		
		if( !isset( $_POST['nonce'] ) or !wp_verify_nonce( $_POST['nonce'], 'dwhtk_nonce_check' ) ) {
			$checked = get_option( 'dwhtk_status' );
			
			wp_send_json( json_encode(
			[
				'checked' => $checked, 
				'result' => 'error', 
				'msg' => __( 'There was a problem, please try again.', 'do-we-have-testing-kits' ),
				]
			) );
		}
			
		$date = current_datetime();
		
		if( !empty( $_POST['checked'] ) and 'true' == $_POST['checked'] ) {
			$msg = __( 'You have succefully updated your site.<br>You DO have testing kits available.', 'do-we-have-testing-kits' );
			update_option( 'dwhtk_status', true );
			$checked = true;
		} else {
			$msg = __( 'You have succefully updated your site.<br>You DO NOT have testing kits available.', 'do-we-have-testing-kits' );
			update_option( 'dwhtk_status', false );
			$checked = false;
		}
		
		update_option( 'dwhtk_time', current_time( 'timestamp', true ) );
		
		wp_send_json( json_encode(
				[
					'checked' => $checked, 
					'result' => 'success', 
					'msg' => $msg,
				]
			) );
		wp_die();
	}
	function init() {
		add_menu_page( 
			__( 'Do We Have Testing Kits', 'do-we-have-testing-kits' ), 
			__( 'Do We Have Testing Kits', 'do-we-have-testing-kits' ), 
			'manage_options', 
			'dwhtk-settings', 
			[$this, 'settings_page'], 
			'dashicons-shield', 
			20 );
	}
	
	function enqueue() {
		wp_register_style( 'dwhtk_style', DWHTK_URL . 'dwhtk_style.css' ); 
		wp_enqueue_style( 'dwhtk_style' );
	
		wp_register_script( 'dwhtk_script', DWHTK_URL . 'dwhtk_script.js', ['jquery'],'1.1', true); 
		wp_enqueue_script( 'dwhtk_script' );
		
				
		$nonce = wp_create_nonce( 'dwhtk_nonce' );
				
		$dwhtk_vars = [ 
			'url' 		=> admin_url( 'admin-ajax.php' ),
			'nonce'		=> $nonce,
			'action'	=> 'is_checked',
			'loading'	=> __( 'Loading...', 'dwhkits' ),
			'error_msg'	=> __( 'There has been an error!', 'do-we-have-testing-kits' ),
			
		];
		
		wp_localize_script( 'dwhtk_script', 'dwhtk_vars', $dwhtk_vars );
				
	}
	
	function dwhtk_widget() {
		wp_add_dashboard_widget('dwhtk_quick', __( 'Do We Have Testing Kits', 'do-we-have-testing-kits' ), [$this, 'dwhtk_widget_view']);		
	}
	
	
	function dwhtk_widget_view() {
		$is_checked = ( true == get_option( 'dwhtk_status' ) ) ? ' checked="checked"' : null;
		?>
		
		<div style="display:flex" id="dwhtk_widget">
			<div style="flex:1; text-align: center;"><h2>No Kits</h2></div>
			<div style="flex:1; text-align: center;"><label class="switch">
			<input type="checkbox" id="dwhtk_slider"<?php echo $is_checked; ?>>
			<span class="slider round"></span>
			</label></div>
			<div style="flex:1; text-align: center;"><h2>Yes Kits<h2></div>
			
		</div>
		<?php wp_nonce_field( 'dwhtk_nonce_check', 'dwhtk_nonce' ); ?>
		<div id="dwhtk_msg_mom">
			<div id="dwhtk_msg"></div>
		</div>
		<?php
	}
	function settings_page() {
		
		?>
		<div class="wrap">
            <div id="icon-options-general" class="icon32"></div>
            <h1>Theme Options</h1>
            <?php $this->show_status(); ?>
			<form method="post" action="options.php">
			<?php
			
			settings_fields( 'dwhtk_section' );
			do_settings_sections( 'dwhtk-settings' );
			submit_button();
			?>
			</form>
		</div>
		<?php
		
	}
	
	function show_status() {
		$is_checked = ( true == get_option( 'dwhtk_status' ) ) ? ' checked="checked"' : null;
		?>	
			<div class="dwhtk_page">
				<div style="display:flex" class="dwhtk_page">
					<div style="flex:1; text-align: center;"><h2>No Kits</h2></div>
					<div style="flex:1; text-align: center;"><label class="switch">
					<input type="checkbox" id="dwhtk_slider"<?php echo $is_checked; ?>>
					<span class="slider round"></span>
					</label></div>
					<div style="flex:1; text-align: center;"><h2>Yes Kits<h2></div>
				
				</div>
				<?php wp_nonce_field( 'dwhtk_nonce_check', 'dwhtk_nonce' ); ?>
				<div id="dwhtk_msg_mom">
					<div id="dwhtk_msg"></div>
				</div>
			</div>
		<?php		
	}
	
	function dwhtk_yes_content() {
		echo '<div class="dwhtk_input">';
		$content = get_option( 'dwhtk_yes_content' );
		wp_editor( $content, 'dwhtk_yes_content' );
		echo '</div>';

	}
	
	function dwhtk_no_content() {
		echo '<div class="dwhtk_input">';
		$content = get_option( 'dwhtk_no_content' );
		wp_editor( $content, 'dwhtk_no_content' );
		echo '</div>';
		
	}
}
